Handbook - Epithelial System Seam Cells
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

EPITHELIAL SYSTEM SEAM CELLS Click pictures for new window with figure and legend, click again for high resolution image
1 Overview In the adult animal, seam cells are arranged as longitudinal rows of 16 cells on the left and right sides of the body, and they are embedded in the cylindrical hyp 7 syncytium (SeamFIG 1). These cells are also sometimes referred to as lateral hypodermal cells, because they share some functions with the major hypodermis, including secreting cuticle and generating the contractile force during elongation of the embryo. Each seam cell is smoothly tapered in shape. At the cell body, the seam completely interrupts the hypodermis, whereas at its narrow end points, hypodermis runs behind it, covering the seam on the medial side (SeamFIG 2). Seam cells are linked to the hypodermis by small adherens junctions along their apical borders and by small gap junctions on their lateral membranes (SeamFIG 2) (see also Gap Junctions). In a newly hatched animal, there are ten seam cells on each side of the animal (H1-H2, V1-V6 and T). All seam cells, except for H0, divide in a stem-cell-like pattern before each molt. Between the L2 and L4 stages, most seam-cell divisions generate an anterior daughter cell that fuses with hyp 7 and a posterior daughter cell that continues to divide until the last molt between L4 and adult stages (see HypFIG 1). At this final molt, the seam cells exit the cell cycle, differential terminally and fuse to make one longitudinal syncytium (Sulston and Horvitz, 1977; Singh and Sulston, 1976). SeamFIG 1: Seam is composed of a longitudinal string of cells on each side of C. elegans. A. Schematic view of left lateral seam cells in an L1-stage larva. At this stage, ten embryonically born individual seam blast cells contact each other through adherens junctions. They are also in close contact with P blast cells on the ventral side. B. Schematic view of left lateral seam cells in adult hermaphrodite. Seam cells have increased in number to 16 on each side through post-embryonic seam divisions. At L4/adult molt, seam cells fuse to one another making one longitudinal syncytium on each side of the adult animal that extends between the hyp 5 and hyp 7 junction at the anterior and the phasmids at the posterior. C. Schematic view of seam cells embedded in the hypodermis, looking from the inside out. Except for the most anterior seam cells, each seam cell has a smoothly tapered oval shape. After mid-L1, all seam cells become embedded within the major hypodermis, hyp 7. The apical face of each seam cell faces the cuticle and remains in contact with the cuticle along the full length of the cell (a, b). At their largest cross section, seam cells come into contact with pseudocoelom through holes in hyp 7 (a). (Gray) Cuticle (c); (beige) hypodermis (h); (orange) seam (s); (yellow) pseudocoelom (p); (bl) basal lamina. SeamFIG 2: Seam cells are embedded in hypodermis. A. The hypodermis is composed of four major longitudinal ridges (ventral, dorsal, and L/R lateral) that are joined circumferentially by thin sheets of cytoplasm. At each original cell body of the seam syncytium, where the nuclei are positioned, the seam completely interrupts hyp 7 (section through B in inset), whereas at the ends of the cells, the seam is so thin that hyp 7 runs behind it, enfolding it completely (section through C in inset). At its apical surface, seam makes adherens junctions (aj) to the hypodermis throughout its length. (Green circles) Muscle quadrants. B. TEM, transverse section representing an area through the seam-cell body in an adult animal. The body of the seam is lodged between the ventral and dorsal parts of the lateral hypodermal ridge. Its basal surface is surrounded by the pseudocoelom, although it is separated from the pseudocoelom by a basal lamina. Its apical surface is in complete register with cuticular alae. (White arrows) Adherens junctions. (Image source: B140 [Hall] A578.) Bar, 1 μm. C. TEM, transverse section representing area through tip of seam cell in an adult animal. At this level, hyp 7 completely wraps around the animal, running behind the seam. The lateral nuclei of the hyp7 syncytium are located on the ventral or dorsal side of the seam at this level. (Int.) Intestine. (Image source: [Hall] 8396-1.) Bar, 1 μm. Similar to the hypodermal cells, seam cells are required for the formation of stage-specific cuticles through synthesis of various collagen proteins (Thein et al., 2003). They also produce alae, a set of raised cuticular ridges that extend longitudinally along the two sides of the animal over the seam cells (SeamFIG 3). Cuticular alae are produced only for the L1 stage, dauer larvae, and adults (DCutFIG 2). There is no alae production in L2, L3 and L4 stages. The adult alae are commonly used as an indicator of hypodermal seam cell terminal differentiation. It has been suggested that longitudinal alae are formed over seam cells during the elongation phase of the embryo by circumferential contraction of the seam cells and seam-specific cuticle (Singh and Sulston, 1978; Sulston et al., 1983). Alae are formed in cuticle over seam cells as a result of the difference in placement of the circular actin filament bundles within these cells, compared to the ventral and dorsal hypodermal cells (Costa et al., 1997, see Cuticle). Seam cells shrink in cell volume during the formation of the dauer stage, leading to diametric shrinkage of the body and formation of alae (DCutFIG 2 & 3, see Dauer Cuticle) (Singh and Sulston, 1978; Melendez et al., 2003). SeamFIG 3: Seam cells make special cuticular structures called alae in L1, dauer and adult stages. The seam cell in each TEM panel is marked by an orange line. Bars, 1 μm. A. TEM, transverse section from the head of an L1-stage animal. (Amp.) Amphid nerve. (Image source: [MRC] L1C 48, right side.) B. TEM, transverse section from the body of an L2-stage animal. There is no ala in the cuticle overlying the seam. (N) Seam nucleus. (Image source: [MRC] N2SE1 L2 179, right side.) C. TEM, transverse section from the body of an L4 animal. There is no ala in the cuticle overlying the seam. (N) Seam nucleus. (Image source: [MRC] JSH 165 L4, right side.) D. TEM, transverse section from the body of an adult-stage animal. Trilaminated adult alae are present over the seam. (Image source: [Hall] N501A Q5 1255.) E. TEM, transverse section from an adult animal at midbody level. Vulval and uterine cells and uterine muscles (um1L/R) are anchored to the lateral seam in this region. (Image source: [MRC] N2 vulva 28.) F. TEM, transverse section from an adult animal at the level of the phasmids. Seam syncytium is about to end and alae have become a single bump in the cuticle. (Image source: [Hall] B140 C5 480.) G. TEM, transverse section from the head of a dauer-stage animal. Dauer-specific alae overlay the seam. (Image source: [Riddle] 50 2 1 710.) H & I. SEM of an adult animal showing the head (H) and tail (I) regions. The trilaminated structure of alae converges into a single ridge over the anterior and posterior (white arrows) ends of the seam. J. DIC image of a wild type adult animal showing the three ridges of the alae. Original magnification, 600x. K. Overlay of DIC and epifluorescence images of a transgenic adult animal expressing the F09D12.15::GFP reporter in the seam. Alae are in register with the seam. Original magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium; McKay et al., 2004.) Seam-cell divisions also generate neurons and glia of specific sensilla. During L1, H2.aa becomes an anterior deirid socket (ADEso) cell. During the L2 stage, one of the granddaughters of the V5 cell, V5pa, becomes a neuroblast that produces the posterior deirid sensillum (PDE neuron, PDE sheath cell and PDE socket cell). Seam-cell lineages also give rise to some neurons of lumbar ganglia (PVW and PVN), tail spike neurons (PHC), and support cells of the phasmids (Phso1, Phso2) (Sulston and Horvitz, 1977). In males, V5pp and V6 generate daughters that form sensory rays instead of making alae (Waring and Kenyon, 1990; Hunter et al., 1999; see also Epithelial System of the Male – Seam and Tail Hypodermis). Tail seam cells on each side (right and left T cells) function as the sockets of the phasmid sensilla in the L1 larva. The opening of the sensillum on each side is sealed by a process that extends from the cell and connects to the sheath cell and hypodermis via adherens junctions (White, 1988). The T-cell lineage ultimately gives rise to phasmid socket cells during later stages of development. In animals that have mutations in heterochronic genes, such as lin (lineage abnormal) and some let (lethal) genes, the normal progression of seam cell fate is disrupted (Ambros and Horvitz, 1984; Slack and Ruvkun; 1997; Ambros, 2000). These animals generate seam cells that inappropriately display cell fate patterns of earlier or later stages, resulting in precocious or retarded seam phenotypes (Liu et al., 1995; Abrahante et al., 1998).
2 Embryonic Development of the Seam Cells Eighteen of the 20 seam cells of the newly hatched larva are produced around 230-250 minutes after first cell division in the embryo. The mothers of the two V5 cells divide only slightly before hatching to produce V5L/R and QL/R, which give rise to posterior lateral ganglia on each side, post-embryonically. All of the embryonically generated seam cells except H0 are blast cells that undergo further divisions (SeamFIG 4) (Sulston et al., 1983). All derive from the AB lineage and AB.arp by itself gives rise to 12 of them (seven on the right and five on the left). The characteristic alae seen in L1 appear just before hatching. SeamFIG 4A-F: Development of the seam through embryonic and post-embryonic stages. A, B, E are epifluorescent images of transgenic animals expressing the ajm-1::GFP reporter in epithelial cells. (Strain source: H. Yu and P. W. Sternberg.) C, D, F are epifluorescence images of transgenic animals expressing the F09D12.15::GFP reporter in the seam. A-F Original magnification, 600x. (Strain source: The Genome BC C. elegans gene expression consortium; McKay et al., 2004.) A. Lima- bean-stage embryo, left lateral view. Ten embryonic seam cells (labeled H0-T) are bounded by hypodermis on the dorsal side and hypodermis and P cells on the ventral side. Cell labeled V5 is the mother of the V5 blast cell at this stage. B. Three- fold-stage embryo, right lateral view. Lateral hypodermal cells change their shape during to elongation, becoming narrower and longer due to contraction of circumferential actin bundles. C. Early-L1-stage animal, left oblique view. Ten seam cells make a string of cells on each side (right-side seam cells are seen as faint). The anteriormost seam cell, H0, ends at the border of hyp 5-hyp 6 (left inset, arrow), whereas the posteriormost seam cell, T, ends at the border of hyp 7-hyp 8 (right inset, arrow) D. Later-stage-L1 animal, left lateral view. All seam cells except for H1, H2, T and H0, have duplicated. The identity of the mother cell is marked underneath its descendants. Their anterior daughters will fuse with the major hypodermis hyp 7. E. Early-L2-stage animal when all seam cells, except for H0 and T, have duplicated, left lateral view. The identity of the original stem cell is given underneath its descendants. H0 does not divide. Anterior daughter of V5p is in the process of generating the posterior deirid (arrow). F. Late- L2-stage animal, left lateral view. After the fusion of their sisters with hyp 7, 15 newly born seam cells elongate over their sisters to make contact with one another (arrow shows V3ppp extending towards V4pap). SeamFIG 4G-I: Development of the seam through embryonic and post-embryonic stages. G. Early- L3-stage animal, left lateral view. Seam cells have undergone their stem-cell division during the L2/3 molt. Their anterior daughters will fuse with hyp 7. A post-deirid sensillum has formed and attaches to the hypodermis through adherens junctions (arrow). H. Late-L4-stage animal, left lateral view. The 16 seam cells have reached their final stage, but have not yet terminally differentiated. Since they have not yet fused, adherens junctions still exist between each seam cell (inset, arrows). I. Adult-stage animal, left lateral view. Seam cells have terminally differentiated and fused to make one syncytium of 16 cells on each side. Adherens junctions between cells have dissolved (inset). Similar to ventral and dorsal hypodermal cells, embryonic seam cells transiently acquire circumferentially oriented actin bundles at the beginning of elongation of the embryo. They are suggested to actively drive hypodermal elongation, whereas dorsal and ventral hypodermal cells change shape passively (SeamFIG 4) (Ding et al., 2004).
3 Post-embryonic Development of Seam Cells At hatching, a row of 10 seam cells on each side of the animal are embedded in hyp 7 and are in close contact with the ventral epithelial (P) cells (SeamFIG 4). The seam cells posterior to H0 round up and divide about 5 hours after hatching. The earliest division is seen in V5, whereas H1 and H2 divide 2.5 and 2 hours later, respectively, than the other seam cells (Podbilewicz and White, 1994; Shemer and Podbilewicz, 2000). Around the middle of the L1 stage, the anterior daughters of V2-V6 extend cytoplasmic processes toward the ventral midline, disrupting the adherens junctions between P cells and isolating left-right P-cell pairs from their neighbors (see HypFIG 6B). About 3 hours after birth, the anterior daughters of V1-V6 and T cells, the posterior daughter of H1 (H1p) and H2ap fuse with hyp 7. The posterior daughters of H2, V1-V6, the anterior daughter of H1, and T.ap become the new seam blast cells and extend long thin processes in both longitudinal directions over their presyncytial sisters. These processes establish contact with each other about 8 hours after hatching (see HypFIG 9A) (Austin and Kenyon, 1994). The seam cells undergo a stem-cell division again at the beginning of the L2, L3 and L4 larval stages, before molting, repeating the pattern of rounding up, cell division, hypodermal fusion, and reestablishment of contact between seam daughters (SeamFIG 4). This cell–cell contact between seam neighbors has been shown to provide signals for establishment of certain cell fates of seam daughters such as the ray/alae switch in males and post-deirid production in both sexes (Waring et al., 1992). Signaling between V5 and its anterior and posterior neighbors has been shown to be critical for V5 to produce posterior deirid cells (Austin and Kenyon, 1994). About the middle of the L4 stage (around 41 hours after hatching) and after the fusion of 13 anterior daughter cells with hyp 7, 16 seam cells on each side terminally differentiate and fuse with one another (SeamFIG 4). These fusions are the last somatic cell fusions seen in C. elegans.
4 List of Seam Cells (See HVT Lineages) 1. Left side seam cells Embryonic (L side) seam cells (do not form a syncytium): H0L H1L (postembryonic blast cell) H2L (postembryonic blast cell) V1L (postembryonic blast cell) V2L (postembryonic blast cell) V3L (postembryonic blast cell) V4L (postembryonic blast cell) V5L (postembryonic blast cell) V6L (postembryonic blast cell) TL (postembryonic blast cell; functions as phasmid socket in L1) Adult (L side ) seam cells (these cells fuse at L4 to make one row of syncytium): H0L H1L.aa H1L.appp H2L.pppp V1L.pappp V1L.ppppp V2L.pappp V2L.ppppp V3L.pappp V3L.ppppp V4L.pappp V4L.ppppp V5L.ppppp (terminally differentiated as seam only in hermaphrodite; blast cell in male) V6L.pappp (terminally differentiated as seam only in hermaphrodite; blast cell in male) V6L.ppppp (terminally differentiated as seam only in hermaphrodite; blast cell in male) TL.appa (terminally differentiated as seam only in hermaphrodite; blast cell in male) Alternate fate seam cells (L side) in adult male: V5L.pppapp fuses with the main seam syncytium V5L.pppppp set cells (male tail seam; does not fuse with main seam and does not make alae) V6L.papapp set cells (male tail seam; does not fuse with main seam and does not make alae) V6L.papppp set cells (male tail seam; does not fuse with main seam and does not make alae) V6L.pppapp set cells (male tail seam; does not fuse with main seam and does not make alae) V6L.pppppp set cells (male tail seam; does not fuse with main seam and does not make alae) 2. Right side seam cells Embryonic (R side) seam cells (do not form a syncytium): H0R H1R (postembryonic blast cell) H2R (postembryonic blast cell) V1R (postembryonic blast cell) V2R (postembryonic blast cell) V3R (postembryonic blast cell) V4R (postembryonic blast cell) V5R (postembryonic blast cell) V6R (postembryonic blast cell) TR (postembryonic blast cell; functions as phasmid socket in L1) Adult (R side ) seam cells (these cells fuse at L4 to make one row of syncytium): H0R H1R.aa H1R.appp H2R.pppp V1R.pappp V1R.ppppp V2R.pappp V2R.ppppp V3R.pappp V3R.ppppp V4R.pappp V4R.ppppp V5R.ppppp (terminally differentiated as seam only in hermaphrodite; blast cell in male) V6R.pappp (terminally differentiated as seam only in hermaphrodite; blast cell in male) V6R.ppppp (terminally differentiated as seam only in hermaphrodite; blast cell in male) TR.appa (terminally differentiated as seam only in hermaphrodite; blast cell in male) Alternate fate seam cells (R side) in adult male: V5R.pppapp fuses with the main seam syncytium V5R.pppppp set cells (male tail seam; does not fuse with main seam and does not make alae) V6R.papapp set cells (male tail seam; does not fuse with main seam and does not make alae) V6R.papppp set cells (male tail seam; does not fuse with main seam and does not make alae) V6R.pppapp set cells (male tail seam; does not fuse with main seam and does not make alae) V6R.pppppp set cells (male tail seam; does not fuse with main seam and does not make alae) 5 References Abrahante, J.E., Miller, E.A. and Rougvie, A.E. 1998. Identification of heterochronic mutants in Caenorhabditis elegans: Temporal misexpression of a collagen::green fluorescent protein fusion gene. Genetics 149: 1335-1351. Article Ambros, V.R. 2000. Control of developmental timing in Caenorhabditis elegans. Current Op. Gen. Dev. 10: 428-433. Abstract Ambros, V.R. and Horvitz, H.R. 1984. Heterochronic mutants of the nematode C. elegans. Science 226: 409-416. Abstract Austin, J. and Kenyon, C. 1994. Cell contact regulates neuroblast formation in the Caenorhabditis elegans lateral epidermis. Development 120: 313-323. Article Costa, M., Draper, B.W. and Priess, J.R. 1997. The role of actin filaments in patterning the Caenorhabditis elegans cuticle. Dev. Biol. 184: 373-384. Article Ding, M., Woo, W-M. and Chisholm, A.D. 2004. The cytoskeleton and epidermal morphogenesis in C.elegans. Exp. Cell Res. 301: 84-90. Abstract Hunter, C.P., Harris, J.M., Maloof, J.N. and Kenyon, C. 1999. Hox gene expression in a single Caenorhabditis elegans cell is regulated by a caudal homolog and intercellular signals that inhibit Wnt signaling. Development 126: 805-814. Article Liu, Z., Kirch, S. and Ambros, V. 1995. The Caenorhabditis elegans heterochronic gene pathway controls stage-specific transcription of collagen genes. Development 121: 2471-2478. Article Melendez, A., Talloczy, Z., Seaman, M., Eskelinen, E.L., Hall, D.H. and Levine, B. 2003. Autophagy genes are essential for dauer development and life-span extension in C elegans. Science 301: 1387-1391. Abstract McKay, S.J., Johnsen, R., Khattra, J., Asano, J., Baillie, D.L., Chan, S., Dube, N., Fang, L., Goszczynsk,i B., Ha, K., Halfnight, E., Hollebakken, R., Huang, P., Hung, K., Jensen, V., Jones, S.J.M., Kai, H., Li, D., Mah,, A., Marr, M., McGhee, J., Newbury, R., Pouzyrev, A., Riddle, D.R., Sonnhammer, E., Tian, H., Tu, D., Tyson, J., Warner, A., Wong, K., Zhao, Z. and Moerman, D.G. 2004. Gene expression profiling of cells, tissues, and developmental stages of the nematode C. elegans. Cold Spring Harbor Symp. Quant. Biol. 68: 159-169.Abstract Podbilewicz, B. and White, J.G. 1994. Cell fusions in the developing epithelial of C. elegans. Dev. Biol. 161: 408-424. Abstract Shemer, G. and Podbilewicz, B. 2000. Fusomorphogenesis: cell fusion in organ formation. Dev. Dyn. 218: 30-51. Article Singh, R. N. and Sulston, J.E. 1978. Some observations on moulting in Caenorhabditis elegans. Nematologica 24:63-71. Abstract Slack, F.J. and Ruvkun, G.B. 1997. Temporal pattern formation by heterochronic genes. Ann. Rev. Gen. 31: 611-634. Abstract Sulston, J.E. and Horvitz, H.R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983. The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev Biol. 100: 64-119. Article Thein, M.C., McCormack, G., Winter, A.D., Johnstone, I.L., Shoemaker, C.B. and Page, A.P. 2003. Caenorhabditis elegans exoskeleton collagen COL-19 : an adult-specific marker for collagen modification and assembly, and the analysis of organismal morphology. Dev. Dyn. 226: 523-539. Article Waring, D.A. and Kenyon, C. 1990. Selective silencing of cell communication influences anteroposterior pattern formation in C. elegans. Cell 601: 23-31. Abstract Waring, D.A., Wrischnik, L.A. and Kenyon, C.J. 1992. Cell signals allow the expression of a preexistent neural pattern in C elegans. Development 116: 457-466. Article White, J. 1988. The Anatomy. In The nematode C. elegans (ed. W. B. Wood). Chapter 4. pp 81-122. Cold Spring Harbor Laboratory Press, New York. Abstract
This chapter should be cited as: Altun, Z.F. and Hall, D.H. 2009. Epithelial system, seam cells. In WormAtlas. doi:10.3908/wormatlas.1.14 Edited for the web by Laura A. Herndon. Last revision: April 30, 2012.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |